.. contents ::

Introduction
------------

This is a python wrapper to the SVOX pico text to speech engine.
The pico TTS engine is found in the android open source 
repositories and is covered by an Apache 2.0 license.
It is very efficient and offers superior speech quality to most other
open source solutions that we could find.

History
-----------

The main port of the pico TTS to linux was done by DougGore/picopi
where this code was forked from.

License
-----------

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Source code
-----------

* https://github.com/sevangelatos/py-ttspico

